@@ -1,18 +1,18 @@
-from .responses.data_classes.FileData import FileData
-from .responses.data_classes.ModpackData import ModpackData
-from .responses.data_classes.UserData import UserData
-from .exceptions.ApiLimitReachedError import ApiLimitReachedError
-from .exceptions.FileNoFoundError import FileNoFoundError
-from .exceptions.ModpackNotFoundError import ModpackNotFoundError
-from .exceptions.NoApiKeyError import NoApiKeyError
-from .exceptions.UserNotFoundError import UserNotFoundError
-from .responses.FileResponse import FileResponse
-from .responses.FilesResponse import FilesResponse
-from .responses.ModpackResponse import ModpackResponse
-from .responses.ModpacksResponse import ModpacksResponse
-from .responses.UserResponse import UserResponse
-from .responses.UsersResponse import UsersResponse
-from .utils import Utils
+from data_classes import FileData
+from data_classes import ModpackData
+from data_classes import UserData
+from exceptions import ApiLimitReachedError
+from exceptions import FileNoFoundError
+from exceptions import ModpackNotFoundError
+from exceptions import NoApiKeyError
+from exceptions import UserNotFoundError
+from responses import FileResponse
+from responses import FilesResponse
+from responses import ModpackResponse
+from responses import ModpacksResponse
+from responses import UserResponse
+from responses import UsersResponse
+from utils import Utils
 
 
 class MpdbApi:
